analyze: Analyze tessellation

Description Usage Arguments Value

Description

Analyze the tessellation of the target class

Usage

1
analyze(tes, func, ...)

Arguments

tes

The tessellation object.

func

The function to use to analyze the critical points of each simplex.

...

Additional arguments required for func

Value

Vector of boolean specifying if all critical points in the each simplex pass the criterion evaluated in func.


mickash/DTFE documentation built on Nov. 16, 2019, 1:49 p.m.