Description Usage Arguments Value
Analyze the tessellation of the target class
1 |
tes |
The tessellation object. |
func |
The function to use to analyze the critical points of each simplex. |
... |
Additional arguments required for func |
Vector of boolean specifying if all critical points in the each simplex pass the criterion evaluated in func.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.